@@ -23,9 +23,7 @@
 #include <QBoxLayout>
 #include <QCheckBox>
 #include <QLabel>
-#include <knuminput.h>
 
-#include <klocale.h>
 #include <QVBoxLayout>
 
 KigCoordinatePrecisionDialog::KigCoordinatePrecisionDialog(bool isUserSpecified, int currentPrecision ) : QDialog()
