@@ -17,23 +17,19 @@
 // 02110-1301, USA.
 
 #include "newscriptwizard.h"
-#include "newscriptwizard.moc"
 
 #include "script_mode.h"
 
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qmenu.h>
-
 #include <QAction>
-#include <QTextEdit>
 #include <QDialog>
+#include <QFontDatabase>
+#include <QLabel>
+#include <QTextEdit>
+#include <QVBoxLayout>
 
+#include <KActionCollection>
 #include <KIconEngine>
 #include <KHelpClient>
-#include <kactioncollection.h>
-#include <kglobalsettings.h>
-#include <klocale.h>
 
 #include <KTextEditor/Document>
 #include <KTextEditor/Editor>
@@ -95,7 +91,7 @@ NewScriptWizard::NewScriptWizard( QWidget* parent, ScriptModeBase* mode, KIconLo
     // simplier KTextEdit
     textedit = new QTextEdit( secondPage );
     textedit->setObjectName( "textedit" );
-    textedit->setFont( KGlobalSettings::fixedFont() );
+    textedit->setFont( QFontDatabase::systemFont( QFontDatabase::FixedFont ) );
     textedit->setAcceptRichText( false );
     lay2->addWidget( textedit );
   }
